@@ -179,51 +179,66 @@ def fix_by_opt(desc, opt, check_cluster):
         if opt.get('nodes'):
             task_desc['InstanceCount'] = trans_nodes(opt['nodes'])
 
+        cluster_id = ''
 
         if opt.get('cluster'):
+
             cluster_info = trans_cluster(opt['cluster'],opt['image'],opt['type'],check_cluster)
 
-            if cluster_info.get('ClusterId'):
+            cluster_id =  cluster_info.get('ClusterId')
+
+            if cluster_id and cluster_id!='':
+
+                # clusterId
                 task_desc['ClusterId'] = cluster_info.get('ClusterId')
                 task_desc['AutoCluster']={}
             else:
+                # auto cluster
                 extend(task_desc['AutoCluster'], cluster_info['AutoCluster'])
 
-            #extend(task_desc, trans_cluster(opt['cluster'],opt['image'],opt['type'],check_cluster))
+
+
+        #extend(task_desc, trans_cluster(opt['cluster'],opt['image'],opt['type'],check_cluster))
+
         else:
             if opt.get('image'):
                 task_desc['AutoCluster']['ImageId'] = opt.get('image')
             if opt.get('type'):
                 task_desc['AutoCluster']['InstanceType'] = opt.get('type')
 
-        if opt.get('resource_type'):
-            task_desc['AutoCluster']['ResourceType'] = opt.get('resource_type')
-        if not task_desc['AutoCluster'].get('ResourceType'):
-            task_desc['AutoCluster']['ResourceType'] = 'OnDemand'
+
+        cluster_id = cluster_id or task_desc['ClusterId']
 
 
+        if not cluster_id or cluster_id=='':
 
-        if opt.get('user_data'):
-            user_data_m = trans_user_data(opt['user_data'])
-            if not task_desc['AutoCluster'].get('UserData'):
-                task_desc['AutoCluster']['UserData'] = {}
-            extend(task_desc['AutoCluster']['UserData'], user_data_m)
+            if opt.get('resource_type'):
+                task_desc['AutoCluster']['ResourceType'] = opt.get('resource_type')
+            if not task_desc['AutoCluster'].get('ResourceType'):
+                task_desc['AutoCluster']['ResourceType'] = 'OnDemand'
 
-        if opt.get('disk') and task_desc.get('AutoCluster'):
-            task_desc['AutoCluster']['Configs']['Disks'] = opt['disk']
+            if opt.get('user_data'):
+                user_data_m = trans_user_data(opt['user_data'])
+                if not task_desc['AutoCluster'].get('UserData'):
+                    task_desc['AutoCluster']['UserData'] = {}
+                extend(task_desc['AutoCluster']['UserData'], user_data_m)
 
+            if opt.get('disk') and task_desc.get('AutoCluster'):
+                if not task_desc['AutoCluster'].get('Configs'):
+                    task_desc['AutoCluster']['Configs']={}
+                task_desc['AutoCluster']['Configs']['Disks'] = opt['disk']
 
         if opt.get('nas_access_group'):
 
-            if not task_desc.get('ClusterId'):
-                task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = opt.get('nas_access_group').split(',')
-            else:
+            # if not task_desc.get('ClusterId'):
+            #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = opt.get('nas_access_group').split(',')
+            # else:
                 task_desc['Mounts']['NAS']['AccessGroup'] = opt.get('nas_access_group').split(',')
 
         if opt.get('nas_file_system'):
-            if task_desc.get('AutoCluster'):
-                task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = opt.get('nas_file_system').split(',')
-            else:
+            # if task_desc.get('AutoCluster'):
+            #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = opt.get('nas_file_system').split(',')
+            # else:
                 task_desc['Mounts']['NAS']['FileSystem'] = opt.get('nas_file_system').split(',')
 
 
@@ -263,8 +278,14 @@ def extend_mount(desc, mount_m):
             desc['InputMapping'][k] = v
             desc['OutputMapping'][v] = k
         elif k.startswith('nas://'):
-            desc['AutoCluster']['Configs']['Mounts']['Entries'] = []
-            desc['AutoCluster']['Configs']['Mounts']['Entries'].append({
+            # desc['AutoCluster']['Configs']['Mounts']['Entries'] = []
+            # desc['AutoCluster']['Configs']['Mounts']['Entries'].append({
+            #     "Destination": v,
+            #     "Source": k,
+            #     "WriteSupport": True
+            # })
+            desc['Mounts']['Entries'] = []
+            desc['Mounts']['Entries'].append({
                 "Destination": v,
                 "Source": k,
                 "WriteSupport": True
@@ -374,19 +395,19 @@ def trans_file_to_job_desc(file, check_cluster):
 
 
             if cf.has_option(DEFAULT, 'nas_access_group'):
-                if task_desc.get('AutoCluster'):
-                    task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = cf.get(DEFAULT,
-                                                                                                 'nas_access_group').split(
-                        ',')
-                else:
+                # if task_desc.get('AutoCluster'):
+                #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = cf.get(DEFAULT,
+                #                                                                                  'nas_access_group').split(
+                #         ',')
+                # else:
                     task_desc['Mounts']['NAS']['AccessGroup'] = cf.get(DEFAULT, 'nas_access_group').split(',')
 
             if cf.has_option(DEFAULT, 'nas_file_system'):
-                if task_desc.get('AutoCluster'):
-                    task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = cf.get(DEFAULT,
-                                                                                                'nas_file_system').split(
-                        ',')
-                else:
+                # if task_desc.get('AutoCluster'):
+                #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = cf.get(DEFAULT,
+                #                                                                                 'nas_file_system').split(
+                #         ',')
+                # else:
                     task_desc['Mounts']['NAS']['FileSystem'] = cf.get(DEFAULT, 'nas_file_system').split(',')
 
 
@@ -412,13 +433,18 @@ def trans_file_to_job_desc(file, check_cluster):
         if cf.has_option(sec,'nodes'):
             task_desc['InstanceCount']=trans_nodes(cf.getint(sec,'nodes'))
 
+        cluster_id=''
         if cf.has_option(sec,'cluster'):
             img = cf.get(sec, 'image') if cf.has_option(sec,'image') else None
             tp = cf.get(sec, 'type') if cf.has_option(sec,'type') else None
 
             cluster_info = trans_cluster(cf.get(sec,'cluster'), img , tp, check_cluster)
-            if cluster_info.get('ClusterId'):
+
+            cluster_id = cluster_info.get('ClusterId')
+
+            if cluster_id and cluster_id!='':
                 task_desc['ClusterId'] = cluster_info.get('ClusterId')
+                task_desc['AutoCluster']= {}
             else:
                 extend(task_desc['AutoCluster'], cluster_info['AutoCluster'])
         else:
@@ -427,35 +453,41 @@ def trans_file_to_job_desc(file, check_cluster):
             if cf.has_option(sec, 'type'):
                 task_desc['AutoCluster']['InstanceType'] = cf.get(sec, 'type')
 
-        if cf.has_option(sec, 'resource_type'):
-            task_desc['AutoCluster']['ResourceType'] = cf.get(sec, 'resource_type')
 
-        if cf.has_option(sec, 'disk') and task_desc.get('AutoCluster'):
-            task_desc['AutoCluster']['Configs']['Disks'] = trans_disk(cf.get(sec, 'disk'))
 
+        if not cluster_id or cluster_id=='':
+
+            if cf.has_option(sec, 'resource_type'):
+                task_desc['AutoCluster']['ResourceType'] = cf.get(sec, 'resource_type')
+
+            if cf.has_option(sec, 'disk') and task_desc.get('AutoCluster'):
+                if not task_desc['AutoCluster'].get('Configs'):
+                    task_desc['AutoCluster']['Configs'] = {}
+                task_desc['AutoCluster']['Configs']['Disks'] = trans_disk(cf.get(sec, 'disk'))
+
+            if cf.has_option(sec, 'user_data'):
+                if not task_desc['AutoCluster']['UserData']:
+                    task_desc['AutoCluster']['UserData'] = {}
+                extend(task_desc['AutoCluster']['UserData'], trans_user_data(cf.get(sec, 'user_data')))
 
         if cf.has_option(sec,'nas_access_group'):
-            if task_desc.get('AutoCluster'):
-                task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = cf.get(sec,'nas_access_group').split(
-                    ',')
-            else:
+            # if task_desc.get('AutoCluster'):
+            #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = cf.get(sec,'nas_access_group').split(
+            #         ',')
+            # else:
                 task_desc['Mounts']['NAS']['AccessGroup'] = cf.get(sec,'nas_access_group').split(',')
 
 
         if cf.has_option(sec, 'nas_file_system'):
-            if task_desc.get('AutoCluster'):
-                task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = cf.get(sec,
-                                                                                             'nas_file_system').split(
-                    ',')
-            else:
+            # if task_desc.get('AutoCluster'):
+            #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['FileSystem'] = cf.get(sec,
+            #                                                                                  'nas_file_system').split(
+            #         ',')
+            # else:
                 task_desc['Mounts']['NAS']['FileSystem'] = cf.get(sec, 'nas_file_system').split(',')
 
 
 
-        if cf.has_option(sec, 'user_data'):
-            if not task_desc['AutoCluster']['UserData']:
-                task_desc['AutoCluster']['UserData'] = {}
-            extend(task_desc['AutoCluster']['UserData'] ,trans_user_data(cf.get(sec, 'user_data')))
 
         if cf.has_option(sec,'env'):
             extend(task_desc['Parameters']['Command']['EnvVars'], trans_env(cf.get(sec,'env')))
@@ -684,12 +716,11 @@ def gen_task_desc():
         "LogMapping": {},
         "InstanceCount": 1,
         "ClusterId": "",
+        "Mounts": {
+            'NAS': {}
+        },
         "AutoCluster": {
-            "Configs": {
-                "Mounts": {
-                    'NAS': {}
-                }
-            }
+
         },
         "MaxRetryCount": 0,
         "Parameters": {
