@@ -2,9 +2,9 @@ from terminal import red, blue, bold, magenta, white
 from .externals.command import Command
 
 from . import const,i18n_util,cli_project,cli_oss
-from .action import login, config, info, cluster, job, cluster_create, cluster_delete, cluster_update, instance_type \
+from .action import login, config, info, cluster,events, job, cluster_create, cluster_delete, cluster_update, instance_type \
     , job_delete, job_restart, job_stop, job_update, job_create, log_fetch, job_submit,checker\
-    ,image,image_create,image_delete,disk_type
+    ,image,image_create,image_delete,disk_type,resource_type
 
 import os
 
@@ -76,10 +76,17 @@ class Cli:
                              func=info.info)
         self.program.action(cmd_info)
 
+        # resource type
+        cmd_resource_type = Command('resource_type', alias=['rt', 'r'],
+                                    description=MSG['resource_type']['description'],
+                                    usage='''Usage: %s resource_type|rt|r [option]
 
+            Examples:
 
-
-
+                1. %s r ''' % (COMMAND, CMD),
+                                    spliter='\n    -----%s---------------------------' % blue('query, show'),
+                                    func=resource_type.list)
+        self.program.action(cmd_resource_type)
 
         # instance type
         cmd_instance_type = Command('instance_type', alias=['it', 't'],
@@ -89,7 +96,6 @@ class Cli:
         Examples:
 
             1. %s it ''' % (COMMAND, CMD),
-                                    spliter='\n    -----%s---------------------------' % blue('query, show'),
                                     func=instance_type.list)
         self.program.action(cmd_instance_type)
 
@@ -105,6 +111,17 @@ class Cli:
                                     func=disk_type.list)
         self.program.action(cmd_disk_type)
 
+        # events
+        cmd_events = Command('event', alias=['e'],
+                                description=MSG['event']['description'],
+                                usage='''Usage: %s event|e [option]
+
+            Examples:
+
+                1. %s e ''' % (COMMAND, CMD),
+                                func=events.list)
+        self.program.action(cmd_events)
+
 
 
 
@@ -270,8 +287,10 @@ class Cli:
 
         1. %s cc cluster1
         2. %s cc cluster2 -n 3
-        3. %s cc cluster2 -i %s -t %s -n 1 -d 'this is description' -u key1:value1,k2:v2''' % (
-                                     COMMAND, CMD, CMD,CMD, IMG_ID, INS_TYPE),
+        3. %s cc cluster2 -i %s -t %s -n 1 -d 'this is description' -u key1:value1,k2:v2
+        4. %s cc cluster3 --notification_topic my-mns-topic --notification_events OnClusterDeleted,OnInstanceActive --notification_endpoint <your_mns_endpoint>    # set notification
+        5. %s cc cluster4 --resource_type Spot  # creating with spot resource type''' % (
+                                     COMMAND, CMD, CMD, CMD, IMG_ID, INS_TYPE , CMD, CMD),
                                      spliter=' ',
                                     # spliter='\n    -----%s----------------' % blue('create, update, delete'),
                                      func=cluster_create.create_cluster)
@@ -288,6 +307,20 @@ class Cli:
         cmd_create_cluster.option("--disk [disk_configs]",
                                   MSG['create_cluster']['option']['disk'],
                                   resolve=cluster_create.trans_disk)
+
+        cmd_create_cluster.option("--resource_type [resource_type]",
+                                  MSG['create_cluster']['option']['resource_type'])
+
+        cmd_create_cluster.option("-m, --mount [kv_pairs]", MSG['create_cluster']['option']['mount'])
+        cmd_create_cluster.option("--nas_access_group [nas_access_group]",
+                              MSG['create_cluster']['option']['nas_access_group'])
+        cmd_create_cluster.option("--nas_file_system [nas_file_system]", MSG['create_cluster']['option']['nas_file_system'])
+
+        cmd_create_cluster.option("--notification_endpoint [mns_endpoint]",
+                              MSG['create_cluster']['option']['notification_endpoint'])
+        cmd_create_cluster.option("--notification_topic [mns_topic]", MSG['create_cluster']['option']['notification_topic'])
+        cmd_create_cluster.option("--notification_events [cluster_events]", MSG['create_cluster']['option']['notification_events'],
+                              resolve=cluster_create.trans_notification_events)
         cmd_create_cluster.option("--show_json",
                               MSG['create_cluster']['option']['show_json'], visible=IS_GOD)
         self.program.action(cmd_create_cluster)
@@ -449,8 +482,10 @@ class Cli:
         3. %s sub "python main.py arg1 arg2" job_name -c cls-xxxxx -p ./my_program/         # set job name, use cluster id, pack a folder and upload
         4. %s sub "python /home/admin/test/main.py" -m oss://bucket/a/b/:/home/admin/test/  # mount an oss path to a local path
         5. %s sub "python test.py" -p test.py --docker myubuntu@oss://bucket/dockers/       # run in docker container
-        6. %s sub --file job.cfg                    # submit a job from job.cfg''' % (
-                                 COMMAND, CMD, CMD, IMG_ID, IMG_ID, CMD, CMD, CMD, CMD),
+        6. %s sub --file job.cfg                    # submit a job from job.cfg
+        7. %s sub --notification_topic my-mns-topic --notification_events OnTaskStopped,OnJobFailed  --notification_endpoint <your_mns_endpoint>          # set notification
+        ''' % (
+                                 COMMAND, CMD, CMD, IMG_ID, IMG_ID, CMD, CMD, CMD, CMD, CMD),
                                  spliter='\n    -----%s----------------' % blue('quick cmd'),
                                  func=job_submit.submit)
 
@@ -472,14 +507,29 @@ class Cli:
         cmd_submit_job.option("-r, --read_mount [kv_pairs]",  MSG['submit']['option']['read_mount'])
         cmd_submit_job.option("-w, --write_mount [kv_pairs]", MSG['submit']['option']['write_mount'])
         cmd_submit_job.option("-m, --mount [kv_pairs]", MSG['submit']['option']['mount'])
+
+        cmd_submit_job.option("--nas_access_group [nas_access_group]",
+                              MSG['submit']['option']['nas_access_group'])
+
+        cmd_submit_job.option("--nas_file_system [nas_file_system]", MSG['submit']['option']['nas_file_system'])
+
         cmd_submit_job.option("--docker [docker]",  MSG['submit']['option']['docker'])
         cmd_submit_job.option("-u,--user_data [kv_pairs]", MSG['submit']['option']['user_data'])
+
+        cmd_submit_job.option("--resource_type [resource_type]",
+                                  MSG['submit']['option']['resource_type'])
         cmd_submit_job.option("--disk [disk_configs]",
                                   MSG['submit']['option']['disk'],
                                   resolve=job_submit.trans_disk)
         cmd_submit_job.option("--lock", MSG['submit']['option']['lock'])
         cmd_submit_job.option("--locale [locale]", MSG['submit']['option']['locale'])
         cmd_submit_job.option("--file [file]",  MSG['submit']['option']['file'])
+        cmd_submit_job.option("--notification_endpoint [mns_endpoint]",  MSG['submit']['option']['notification_endpoint'])
+        cmd_submit_job.option("--notification_topic [mns_topic]", MSG['submit']['option']['notification_topic'])
+        cmd_submit_job.option("--notification_events [job_events]", MSG['submit']['option']['notification_events'],
+                              resolve=job_submit.trans_notification_events)
+
+
         cmd_submit_job.option("--show_json",
                               MSG['submit']['option']['show_json'], visible=IS_GOD)
         self.program.action(cmd_submit_job)
